==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Získání přístupových tokenů selhalo. Ověřte že klíč aplikace a tajné heslo jsou správné.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Získání přístupových tokenů selhalo. Ověřte že klíč aplikace a tajné heslo jsou správné.",
    "Please provide a valid app key and secret." : "Zadejte prosím platný klíč a tajné heslo aplikace.",
    "Step 1 failed. Exception: %s" : "Selhal krok 1. Výjimka: %s",
    "Step 2 failed. Exception: %s" : "Selhal krok 2. Výjimka: %s",
    "External storage" : "Externí úložiště",
    "Storage with id \"%i\" not found" : "Úložiště s id \"%i\" nebylo nalezeno",
    "Invalid backend or authentication mechanism class" : "Neplatný backend nebo třída ověřovacího mechanismu",
    "Invalid mount point" : "Neplatný přípojný bod",
    "Objectstore forbidden" : "Úložiště objektů zakázáno",
    "Invalid storage backend \"%s\"" : "Neplatná služba úložiště \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nebylo povoleno použítí služby \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nebylo povoleno použití ověřovacího mechanismu \"%s\"",
    "Unsatisfied backend parameters" : "Neuspokojivé parametry služby",
    "Unsatisfied authentication mechanism parameters" : "Neuspokojivé parametry ověřovacího mechanismu",
    "Insufficient data: %s" : "Nedostatečná data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Úložiště s id \"%i\" uživatelé nemohou upravovat",
    "Personal" : "Osobní",
    "System" : "Systém",
    "Grant access" : "Povolit přístup",
    "Access granted" : "Přístup povolen",
    "Error configuring OAuth1" : "Chyba nastavení OAuth1",
    "Error configuring OAuth2" : "Chyba nastavení OAuth2",
    "Generate keys" : "Vytvořit klíče",
    "Error generating key pair" : "Chyba při vytváření páru klíčů",
    "Enable encryption" : "Povolit šifrování",
    "Enable previews" : "Povolit náhledy",
    "Enable sharing" : "Povolit sdílení",
    "Check for changes" : "Zkontrolovat změny",
    "Never" : "Nikdy",
    "Once every direct access" : "Jednou pro každý přímý přístup",
    "All users. Type to select user or group." : "Všichni uživatelé. Začněte psát pro výběr uživatelů a skupin.",
    "(group)" : "(skupina)",
    "Admin defined" : "Nastaveno administrátorem",
    "Saved" : "Uloženo",
    "Empty response from the server" : "Prázdná odpověď serveru",
    "Couldn't access. Please logout and login to activate this mount point" : "Nelze připojit. Pro aktivaci tohoto přípojného bodu se prosím odhlašte a znovu přihlašte",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Nelze obdržet informaci z ownCloud serveru: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nelze obdržet seznam vzdálených přípojných bodů: {type}",
    "There was an error with message: " : "Došlo k chybě s tímto hlášením:",
    "External mount error" : "Chyba vzdáleného úložiště",
    "external-storage" : "external-storage",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Nelze obdržet seznam síťových úložišť systému Windows: prázdná odpověď serveru",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Některá z nastavených vzdálených úložišť nejsou připojena. Pro více informací prosím klikněte na červenou šipku(y)",
    "Please enter the credentials for the {mount} mount" : "Zadejte prosím přihlašovací údaje k přípojnému bodu {mount}",
    "Username" : "Uživatelské jméno",
    "Password" : "Heslo",
    "Credentials saved" : "Přihlašovací údaje uloženy",
    "Credentials saving failed" : "Uložení přihlašovacích údajů selhalo",
    "Credentials required" : "Vyžadovány přihlašovací údaje",
    "Save" : "Uložit",
    "Access key" : "Přístupový klíč",
    "Secret key" : "Tajný klíč",
    "Builtin" : "Zabudované",
    "None" : "Žádné",
    "OAuth1" : "OAuth1",
    "App key" : "Klíč aplikace",
    "App secret" : "Tajemství aplikace",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientské ID",
    "Client secret" : "Klientské tajemství",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Jméno vlastníka",
    "Identity endpoint URL" : "Identifikační koncový bod URL",
    "Rackspace" : "Rackspace",
    "API key" : "Klíč API",
    "Username and password" : "Uživatelské jméno a heslo",
    "Log-in credentials, save in session" : "Přihlašovací údaje, ukládat v sezení",
    "RSA public key" : "RSA veřejný klíč",
    "Public key" : "Veřejný klíč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Kraj",
    "Enable SSL" : "Povolit SSL",
    "Enable Path Style" : "Povolit Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdálený podadresář",
    "Secure https://" : "Zabezpečené https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Počítač",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Místní",
    "Location" : "Umístění",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Kořen",
    "SFTP with secret key login" : "SFTP login s tajným klíčem",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Sdílet",
    "Domain" : "Doména",
    "SMB / CIFS using OC login" : "SMB / CIFS za použití přihlašovacího jména OC",
    "Username as share" : "Uživatelské jméno jako sdílený adresář",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Jméno služby",
    "Request timeout (seconds)" : "Čas vypršení požadavku (sekundy)",
    "<b>Note:</b> " : "<b>Poznámka:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> cURL podpora v PHP není povolena nebo nainstalována. Není možné připojení %s. Prosím požádejte svého správce systému ať ji nainstaluje.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> FTP podpora v PHP není povolena nebo nainstalována. Není možné připojení %s. Prosím požádejte svého správce systému ať ji nainstaluje.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> \"%s\" není instalováno. Není možné připojení %s. Prosím požádejte svého správce systému o instalaci.",
    "No external storage configured" : "Není nakonfigurováno žádné externí úložiště",
    "You can add external storages in the personal settings" : "Můžete přidat externí úložiště v osobních nastaveních",
    "Name" : "Název",
    "Storage type" : "Typ úložiště",
    "Scope" : "Rozsah",
    "External Storage" : "Externí úložiště",
    "Folder name" : "Název složky",
    "Authentication" : "Ověření",
    "Configuration" : "Nastavení",
    "Available for" : "Dostupné pro",
    "Add storage" : "Přidat úložiště",
    "Advanced settings" : "Pokročilá nastavení",
    "Delete" : "Smazat",
    "Allow users to mount external storage" : "Povolit uživatelům připojení externího úložiště",
    "Allow users to mount the following external storage" : "Povolit uživatelů připojit následující externí úložiště"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Získání přístupových tokenů selhalo. Ověřte že klíč aplikace a tajné heslo jsou správné.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Získání přístupových tokenů selhalo. Ověřte že klíč aplikace a tajné heslo jsou správné.",
    "Please provide a valid app key and secret." : "Zadejte prosím platný klíč a tajné heslo aplikace.",
    "Step 1 failed. Exception: %s" : "Selhal krok 1. Výjimka: %s",
    "Step 2 failed. Exception: %s" : "Selhal krok 2. Výjimka: %s",
    "External storage" : "Externí úložiště",
    "Storage with id \"%i\" not found" : "Úložiště s id \"%i\" nebylo nalezeno",
    "Invalid backend or authentication mechanism class" : "Neplatný backend nebo třída ověřovacího mechanismu",
    "Invalid mount point" : "Neplatný přípojný bod",
    "Objectstore forbidden" : "Úložiště objektů zakázáno",
    "Invalid storage backend \"%s\"" : "Neplatná služba úložiště \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nebylo povoleno použítí služby \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nebylo povoleno použití ověřovacího mechanismu \"%s\"",
    "Unsatisfied backend parameters" : "Neuspokojivé parametry služby",
    "Unsatisfied authentication mechanism parameters" : "Neuspokojivé parametry ověřovacího mechanismu",
    "Insufficient data: %s" : "Nedostatečná data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Úložiště s id \"%i\" uživatelé nemohou upravovat",
    "Personal" : "Osobní",
    "System" : "Systém",
    "Grant access" : "Povolit přístup",
    "Access granted" : "Přístup povolen",
    "Error configuring OAuth1" : "Chyba nastavení OAuth1",
    "Error configuring OAuth2" : "Chyba nastavení OAuth2",
    "Generate keys" : "Vytvořit klíče",
    "Error generating key pair" : "Chyba při vytváření páru klíčů",
    "Enable encryption" : "Povolit šifrování",
    "Enable previews" : "Povolit náhledy",
    "Enable sharing" : "Povolit sdílení",
    "Check for changes" : "Zkontrolovat změny",
    "Never" : "Nikdy",
    "Once every direct access" : "Jednou pro každý přímý přístup",
    "All users. Type to select user or group." : "Všichni uživatelé. Začněte psát pro výběr uživatelů a skupin.",
    "(group)" : "(skupina)",
    "Admin defined" : "Nastaveno administrátorem",
    "Saved" : "Uloženo",
    "Empty response from the server" : "Prázdná odpověď serveru",
    "Couldn't access. Please logout and login to activate this mount point" : "Nelze připojit. Pro aktivaci tohoto přípojného bodu se prosím odhlašte a znovu přihlašte",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Nelze obdržet informaci z ownCloud serveru: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nelze obdržet seznam vzdálených přípojných bodů: {type}",
    "There was an error with message: " : "Došlo k chybě s tímto hlášením:",
    "External mount error" : "Chyba vzdáleného úložiště",
    "external-storage" : "external-storage",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Nelze obdržet seznam síťových úložišť systému Windows: prázdná odpověď serveru",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Některá z nastavených vzdálených úložišť nejsou připojena. Pro více informací prosím klikněte na červenou šipku(y)",
    "Please enter the credentials for the {mount} mount" : "Zadejte prosím přihlašovací údaje k přípojnému bodu {mount}",
    "Username" : "Uživatelské jméno",
    "Password" : "Heslo",
    "Credentials saved" : "Přihlašovací údaje uloženy",
    "Credentials saving failed" : "Uložení přihlašovacích údajů selhalo",
    "Credentials required" : "Vyžadovány přihlašovací údaje",
    "Save" : "Uložit",
    "Access key" : "Přístupový klíč",
    "Secret key" : "Tajný klíč",
    "Builtin" : "Zabudované",
    "None" : "Žádné",
    "OAuth1" : "OAuth1",
    "App key" : "Klíč aplikace",
    "App secret" : "Tajemství aplikace",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klientské ID",
    "Client secret" : "Klientské tajemství",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Jméno vlastníka",
    "Identity endpoint URL" : "Identifikační koncový bod URL",
    "Rackspace" : "Rackspace",
    "API key" : "Klíč API",
    "Username and password" : "Uživatelské jméno a heslo",
    "Log-in credentials, save in session" : "Přihlašovací údaje, ukládat v sezení",
    "RSA public key" : "RSA veřejný klíč",
    "Public key" : "Veřejný klíč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Kraj",
    "Enable SSL" : "Povolit SSL",
    "Enable Path Style" : "Povolit Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdálený podadresář",
    "Secure https://" : "Zabezpečené https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Počítač",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Místní",
    "Location" : "Umístění",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Kořen",
    "SFTP with secret key login" : "SFTP login s tajným klíčem",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Sdílet",
    "Domain" : "Doména",
    "SMB / CIFS using OC login" : "SMB / CIFS za použití přihlašovacího jména OC",
    "Username as share" : "Uživatelské jméno jako sdílený adresář",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Jméno služby",
    "Request timeout (seconds)" : "Čas vypršení požadavku (sekundy)",
    "<b>Note:</b> " : "<b>Poznámka:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> cURL podpora v PHP není povolena nebo nainstalována. Není možné připojení %s. Prosím požádejte svého správce systému ať ji nainstaluje.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> FTP podpora v PHP není povolena nebo nainstalována. Není možné připojení %s. Prosím požádejte svého správce systému ať ji nainstaluje.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Poznámka:</b> \"%s\" není instalováno. Není možné připojení %s. Prosím požádejte svého správce systému o instalaci.",
    "No external storage configured" : "Není nakonfigurováno žádné externí úložiště",
    "You can add external storages in the personal settings" : "Můžete přidat externí úložiště v osobních nastaveních",
    "Name" : "Název",
    "Storage type" : "Typ úložiště",
    "Scope" : "Rozsah",
    "External Storage" : "Externí úložiště",
    "Folder name" : "Název složky",
    "Authentication" : "Ověření",
    "Configuration" : "Nastavení",
    "Available for" : "Dostupné pro",
    "Add storage" : "Přidat úložiště",
    "Advanced settings" : "Pokročilá nastavení",
    "Delete" : "Smazat",
    "Allow users to mount external storage" : "Povolit uživatelům připojení externího úložiště",
    "Allow users to mount the following external storage" : "Povolit uživatelů připojit následující externí úložiště",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Některá z nastavených vzdálených úložišť nejsou připojena. Pro více informací prosím klikněte na červenou šipku(y)"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
